
#ifndef _C133_dy6632_
#define _C133_dy6632_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F2584_32529(EIF_REFERENCE);
extern void EIF_Minit6632(void);

#ifdef __cplusplus
}
#endif

#endif
